==> quick_resto_API-1.0.8.tar.gz: quick_resto_API-1.0.8/quick_resto_API/operations_with_objects/modules/packing_unit_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.packing_unit import PackingUnit

class PackingUnitOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.packingunits"

    def get_list_of_packing_unit(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(PackingUnit(**object))

        return result

    def get_tree_of_packing_unit(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result = list()

        for object in json_response:
            result.append(PackingUnit(**object))

        return result

    def get_packing_unit(self, objectId: int, objectRid: int = None) -> PackingUnit:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return PackingUnit(**json_response)

    def get_packing_unit_with_subobjects(self, objectId: int, objectRid: int = None) -> PackingUnit:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return PackingUnit(**json_response)

    def create_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def update_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def remove_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def recover_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

==> quick_resto_API-1.1.tar.gz: quick_resto_API-1.1/quick_resto_API/operations_with_objects/modules/packing_unit_operations.py <==
from quick_resto_API.operations_with_objects.operations_with_objects import OperationsWithObjects
from quick_resto_API.operations_with_objects.system_object import SystemObject
from quick_resto_API.quick_resto_api import QuickRestoApi
from quick_resto_API.quick_resto_objects.modules.core.packing_unit import PackingUnit

class PackingUnitOperations(SystemObject):
    def __init__(self, api: QuickRestoApi):
        self._operations_with_objects = OperationsWithObjects(api)

        self._module_name:str = "core.dictionaries.packingunits"

    def get_list_of_packing_unit(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[PackingUnit]:

        json_response = self._operations_with_objects.getList(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[PackingUnit] = list()

        for object in json_response:
            result.append(PackingUnit(**object))

        return result

    def get_tree_of_packing_unit(self, ownerContextId: int = None, ownerContextClassName: str = None,
                           showDeleted: bool = False) -> list[PackingUnit]:

        json_response = self._operations_with_objects.getTree(self._module_name,
                                                              ownerContextId, ownerContextClassName, showDeleted).json()

        result:list[PackingUnit] = list()

        for object in json_response:
            result.append(PackingUnit(**object))

        return result

    def get_packing_unit(self, objectId: int, objectRid: int = None) -> PackingUnit:
        json_response = self._operations_with_objects.getObject(self._module_name, objectId, objectRid).json()

        return PackingUnit(**json_response)

    def get_packing_unit_with_subobjects(self, objectId: int, objectRid: int = None) -> PackingUnit:
        json_response = self._operations_with_objects.getObjectWithSubobjects(self._module_name, objectId, objectRid).json()

        return PackingUnit(**json_response)

    def create_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.createObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def update_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.updateObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def remove_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.removeObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)

    def recover_packing_unit(self, object: PackingUnit,ownerContextId: int = None,
                                                ownerContextClassName: str = None, parentContextId: int = None,
                                                parentContextClassName: str = None) -> PackingUnit:

        json_response = self._operations_with_objects.recoverObject(object, self._module_name, ownerContextId, 
                                                ownerContextClassName, parentContextId, parentContextClassName).json()

        return PackingUnit(**json_response)
